pub fn level() -> LevelFilterExpand description
Current threshold — useful for diagnostic natives that want to report the active level back to scripts.
pub fn level() -> LevelFilterCurrent threshold — useful for diagnostic natives that want to report the active level back to scripts.