pub unsafe fn create_repeating_timer(
timers: *mut ITimersComponent,
handler: *mut TimerTimeOutHandler,
interval_ms: i64,
) -> *mut ITimerExpand description
Creates a repeating timer on the Open Multiplayer server.
Returns the server’s ITimer* (non-owning — the server owns it). Use
kill_timer at shutdown to stop it and free the server’s resources.
Safety
timersmust be a validITimersComponentpointer (fromquery_timers_component)handlermust remain alive while the timer is active (allocate on the heap viaBox::into_raw)