pub unsafe fn event_handler_count<H>(
dispatcher: *mut EventDispatcher<H>,
) -> usizeExpand description
count() — how many handlers are registered.
Safety
dispatcher must come from an accessor, or be null.
pub unsafe fn event_handler_count<H>(
dispatcher: *mut EventDispatcher<H>,
) -> usizecount() — how many handlers are registered.
dispatcher must come from an accessor, or be null.