subobject_ptr

Function subobject_ptr 

pub unsafe fn subobject_ptr(obj: *mut u8, offset: isize) -> Option<*mut u8>
Returns the subobject pointer at offset bytes from obj.

For the primary base class (at offset 0), offset = 0. For secondary bases, the offset is determined by the sizeof of the preceding bases in C++.

Returns None if obj is null.

Safety

obj must be a valid pointer (or null). offset must be the correct offset of the subobject — passing the wrong offset produces an invalid pointer.