pub fn component_name<T>(c: &T) -> Option<String>where
T: OmpComponentHandle,Expand description
Reads the component name by calling componentName() (slot [6] of the IComponent vtable).
Returns a String with the UTF-8 name (copied — does not retain pointers from the component).
None if the component or vtable are null, the slot is empty, the returned
StringView is invalid, or the bytes are not valid UTF-8.