pub fn component_version<T>(c: &T) -> Option<SemanticVersion>where
T: OmpComponentHandle,Expand description
Reads the component version by calling componentVersion() (slot [8] of the IComponent vtable).
Official Open Multiplayer components return the server version (e.g. 1.5.8.3079).
None if the component or vtable are null or the slot is empty.